import de.fhpotsdam.unfolding.*;
import de.fhpotsdam.unfolding.geo.*;
import de.fhpotsdam.unfolding.marker.*;
import de.fhpotsdam.unfolding.utils.*;

UnfoldingMap map;

ArrayList<Marker> bikeStations = new ArrayList();
int maxBikesAvailable = 0;

void setup() {
  size(800, 600);
  smooth();

  // Create interactive map centered around London
  map = new UnfoldingMap(this);
  map.zoomAndPanTo(12, new Location(51.500, -0.118));
  MapUtils.createDefaultEventDispatcher(this, map);

    // Read data from CSV
  Table bikeDataCSV = loadTable("http://api.bike-stats.co.uk/service/rest/bikestats?format=csv", "header, csv");
  for (TableRow bikeStationRow : bikeDataCSV.rows()) {
  
    // Create Location
    float lat = bikeStationRow.getFloat("Latitude");
    float lng = bikeStationRow.getFloat("Longitude");
    Location location = new Location(lat, lng);
    
    // Create bikeStation marker 
    BikeStationMarker bsMarker = new BikeStationMarker(location);
    bsMarker.id = bikeStationRow.getInt("ID");
    bsMarker.name = bikeStationRow.getString("Name");
    bsMarker.bikesAvailable = bikeStationRow.getInt("BikesAvailable");

    // Add to list of all bike stations
    bikeStations.add(bsMarker);

    // Statistics (well, sort of)
    maxBikesAvailable = max(maxBikesAvailable, bsMarker.bikesAvailable);
  }

  map.addMarkers(bikeStations);
}

void draw() {
  map.draw();
}

